@@ -67,7 +67,6 @@ from pymc.pytensorf import (
 )
 from pymc.util import (
     UNSET,
-    VarName,
     WithMemoization,
     _UnsetType,
     get_transformed_name,
@@ -369,10 +368,8 @@ class Model(WithMemoization, metaclass=ContextMeta):
         import numpy as np
 
         coords = {
-            "feature",
-            ["A", "B", "C"],
-            "trial",
-            [1, 2, 3, 4, 5],
+            "feature": ["A", "B", "C"],
+            "trial": [1, 2, 3, 4, 5],
         }
 
         with pm.Model(coords=coords) as model:
@@ -1968,7 +1965,7 @@ class Model(WithMemoization, metaclass=ContextMeta):
     def to_graphviz(
         self,
         *,
-        var_names: Iterable[VarName] | None = None,
+        var_names: Iterable[str] | None = None,
         formatting: str = "plain",
         save: str | None = None,
         figsize: tuple[int, int] | None = None,
@@ -2172,7 +2169,7 @@ def compile_fn(
     )
 
 
-def Point(*args, filter_model_vars=False, **kwargs) -> dict[VarName, np.ndarray]:
+def Point(*args, filter_model_vars=False, **kwargs) -> dict[str, np.ndarray]:
     """Build a point.
 
     Uses same args as dict() does.
