@@ -1,4 +1,4 @@
-#   Copyright 2024 The PyMC Developers
+#   Copyright 2024 - present The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -39,10 +39,11 @@ from pymc.distributions.custom import CustomDistRV, CustomSymbolicDistRV
 from pymc.distributions.distribution import _support_point
 from pymc.logprob.abstract import _icdf, _logcdf, _logprob
 from pymc.model import Model, modelcontext
+from pymc.progress_bar import CustomProgress
 from pymc.sampling.parallel import _cpu_count
 from pymc.smc.kernels import IMH
 from pymc.stats.convergence import log_warnings, run_convergence_checks
-from pymc.util import CustomProgress, RandomState, _get_seeds_per_chain
+from pymc.util import RandomState, _get_seeds_per_chain
 
 
 def sample_smc(
@@ -58,6 +59,7 @@ def sample_smc(
     return_inferencedata=True,
     idata_kwargs=None,
     progressbar=True,
+    compile_kwargs: dict | None = None,
     **kernel_kwargs,
 ) -> InferenceData | MultiTrace:
     r"""
@@ -95,6 +97,9 @@ def sample_smc(
         Keyword arguments for :func:`pymc.to_inference_data`.
     progressbar : bool, optional, default True
         Whether or not to display a progress bar in the command line.
+    compile_kwargs: dict, optional
+        Keyword arguments to pass to pytensor.function
+
     **kernel_kwargs : dict, optional
         Keyword arguments passed to the SMC_kernel. The default IMH kernel takes the following keywords:
 
@@ -102,10 +107,11 @@ def sample_smc(
           Determines the change of beta from stage to stage, i.e. indirectly the number of stages,
           the higher the value of `threshold` the higher the number of stages. Defaults to 0.5.
           It should be between 0 and 1.
-            correlation_threshold : float, default 0.01
-                The lower the value the higher the number of MCMC steps computed automatically.
-                Defaults to 0.01. It should be between 0 and 1.
-        Keyword arguments for other kernels should be checked in the respective docstrings.
+        correlation_threshold : float, default 0.01
+            The lower the value the higher the number of MCMC steps computed automatically.
+            Defaults to 0.01. It should be between 0 and 1.
+
+        Additional keyword arguments for other kernels should be checked in the respective docstrings.
 
     Notes
     -----
@@ -160,6 +166,11 @@ def sample_smc(
     else:
         cores = min(chains, cores)
 
+    if compile_kwargs is None:
+        compile_kwargs = {}
+
+    kernel_kwargs["compile_kwargs"] = compile_kwargs
+
     random_seed = _get_seeds_per_chain(random_state=random_seed, chains=chains)
 
     model = modelcontext(model)
@@ -263,7 +274,7 @@ def _save_sample_stats(
         if idata_kwargs is not None:
             ikwargs.update(idata_kwargs)
         idata = to_inference_data(trace, **ikwargs)
-        idata = InferenceData(**idata, sample_stats=sample_stats)
+        idata = InferenceData(**idata, sample_stats=sample_stats)  # type: ignore[arg-type]
 
     return sample_stats, idata
 
