@@ -1,4 +1,4 @@
-#   Copyright 2024 The PyMC Developers
+#   Copyright 2024 - present The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -36,9 +36,8 @@ import pymc as pm
 from pymc.blocking import DictToArrayBijection, RaveledVars
 from pymc.initial_point import make_initial_point_fn
 from pymc.model import modelcontext
+from pymc.progress_bar import CustomProgress, default_progress_theme
 from pymc.util import (
-    CustomProgress,
-    default_progress_theme,
     get_default_varnames,
     get_value_vars_from_user_vars,
 )
@@ -186,7 +185,7 @@ def find_MAP(
 
     mx0 = RaveledVars(mx0, x0.point_map_info)
     unobserved_vars = get_default_varnames(model.unobserved_value_vars, include_transformed)
-    unobserved_vars_values = model.compile_fn(unobserved_vars)(
+    unobserved_vars_values = model.compile_fn(inputs=model.value_vars, outs=unobserved_vars)(
         DictToArrayBijection.rmap(mx0, start)
     )
     mx = {var.name: value for var, value in zip(unobserved_vars, unobserved_vars_values)}
